import React, { useState, useEffect } from "react";
import Modal from "../general/Modal";
import Table from "../general/Table";
import DataService from "../DataService";
import Product from "../models/Product";
import Supplier from "../models/Supplier";

export default function GetSomeSuppliers(props) {
    const url = 'order/someSuppliers/'
    const productUrl = 'product/'

    const headers = [
        { name: 'name', label: 'Поставщик' },
        { name: 'license', label: 'Лицензия' }
    ];

    const transformer = (data) => new Supplier(data)
    const transformerProduct = (data) => new Product(data)

    const [suppliers, setSuppliers] = useState([])
    const [products, setProducts] = useState([])
    const [product, setProduct] = useState(new Product())

    const [modalHeader, setModalHeader] = useState('')
    const [modalConfirm, setModalConfirm] = useState('')
    const [modalVisible, setModalVisible] = useState(false)

    useEffect(() => {
        loadItems()
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);

    const loadItems = () => {
        DataService.readAll(productUrl, transformerProduct).then(data =>{
            console.log(data)
            setProducts(data)
        })
    }

    const chooseProduct = () => {
        setModalHeader('Добавление')
        setModalConfirm('Добавить')
        setModalVisible(true)
    }

    const save = () => {
        console.log(product)
        DataService.getSomeSuppliers(`${url}${product.id}`)
        .then(data => setSuppliers(data))
    }

    const handleChooseProduct = (event) => {
        // console.log(event.target.id)
        // console.log(event.target.value)
       setProduct({ ...product, [event.target.id]: event.target.value })
    }

    const handleTableClick = (tableSelectedItems) => console.log("")
    const handleTableDblClick = (tableSelectedItem) => console.log("")

    const hideModal = () => {
        setModalVisible(false)
    }
    const modalDone = () => save()

  return (
    <>
        <button type="button" className="btn btn-success" onClick={chooseProduct}>Выбрать продукт</button>
        
        <Table 
            headers={headers} 
            items={suppliers}
            selectable={false}
            onClick={handleTableClick}
            onDblClick={handleTableDblClick}/>
        <Modal
            header={modalHeader}
            confirm={modalConfirm}
            visible={modalVisible} 
            onHide={hideModal}
            onDone={modalDone}> 
                <div className="mb-3">
                    <p className="h4" htmlFor="id">Продукт</p>
                    <select id="id" className="form-select" required
                        value={product.id} onChange={handleChooseProduct}>
                        <option disabled value="">Укажите продукт</option>
                        {
                            products.map(product => 
                                <option key={product.id} value={product.id}>{product.name}</option>
                            )
                        }
                    </select>
                </div> 
        </Modal>
    </>
  );
}